@@ -13,9 +13,13 @@ typedef Eo Ecore_Audio_Out_Sndfile;
 
 
 #endif
+/** Ecore audio output to the sndfile library.
+ *
+ * @ingroup Ecore_Audio_Out_Sndfile
+ */
 #define ECORE_AUDIO_OUT_SNDFILE_CLASS ecore_audio_out_sndfile_class_get()
 
-EAPI const Eo_Class *ecore_audio_out_sndfile_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *ecore_audio_out_sndfile_class_get(void);
 
 
 #endif
