@@ -15,7 +15,7 @@ typedef Eo Efl_Player;
 #endif
 #define EFL_PLAYER_INTERFACE efl_player_interface_get()
 
-EAPI const Eo_Class *efl_player_interface_get(void) EINA_CONST;
+EWAPI const Eo_Class *efl_player_interface_get(void);
 
 /**
  * @brief Whether or not the object data can be played.
@@ -24,7 +24,16 @@ EAPI const Eo_Class *efl_player_interface_get(void) EINA_CONST;
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_playable_get(void);
+EOAPI Eina_Bool efl_player_playable_get(const Eo *obj);
+
+/**
+ * @brief Get play/pause state of the media file.
+ *
+ * @return true if playing, false otherwise.
+ *
+ * @ingroup Efl_Player
+ */
+EOAPI Eina_Bool efl_player_play_get(const Eo *obj);
 
 /**
  * @brief Set play/pause state of the media file.
@@ -36,16 +45,19 @@ EOAPI Eina_Bool efl_player_playable_get(void);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_play_set(Eina_Bool play);
+EOAPI void efl_player_play_set(Eo *obj, Eina_Bool play);
 
 /**
- * @brief Get play/pause state of the media file.
+ * @brief Get the position in the media file.
  *
- * @return true if playing, false otherwise.
+ * The position is returned as the number of seconds since the beginning of the
+ * media file.
+ *
+ * @return The position (in seconds).
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_play_get(void);
+EOAPI double efl_player_position_get(const Eo *obj);
 
 /**
  * @brief Set the position in the media file.
@@ -58,19 +70,7 @@ EOAPI Eina_Bool efl_player_play_get(void);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_position_set(double sec);
-
-/**
- * @brief Get the position in the media file.
- *
- * The position is returned as the number of seconds since the beginning of the
- * media file.
- *
- * @return The position (in seconds).
- *
- * @ingroup Efl_Player
- */
-EOAPI double efl_player_position_get(void);
+EOAPI void efl_player_position_set(Eo *obj, double sec);
 
 /**
  * @brief Get how much of the file has been played.
@@ -82,19 +82,7 @@ EOAPI double efl_player_position_get(void);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_progress_get(void);
-
-/**
- * @brief Control the play speed of the media file.
- *
- * This function control the speed with which the media file will be played.
- * 1.0 represents the normal speed, 2 double speed, 0.5 half speed and so on.
- *
- * @param[in] speed The play speed in the [0, infinity) range.
- *
- * @ingroup Efl_Player
- */
-EOAPI void efl_player_play_speed_set(double speed);
+EOAPI double efl_player_progress_get(const Eo *obj);
 
 /**
  * @brief Control the play speed of the media file.
@@ -106,21 +94,19 @@ EOAPI void efl_player_play_speed_set(double speed);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_play_speed_get(void);
+EOAPI double efl_player_play_speed_get(const Eo *obj);
 
 /**
- * @brief Control the audio volume.
+ * @brief Control the play speed of the media file.
  *
- * Controls the audio volume of the stream being played. This has nothing to do
- * with the system volume. This volume will be multiplied by the system volume.
- * e.g.: if the current volume level is 0.5, and the system volume is 50%, it
- * will be 0.5 * 0.5 = 0.25.
+ * This function control the speed with which the media file will be played.
+ * 1.0 represents the normal speed, 2 double speed, 0.5 half speed and so on.
  *
- * @param[in] volume The volume level
+ * @param[in] speed The play speed in the [0, infinity) range.
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_audio_volume_set(double volume);
+EOAPI void efl_player_play_speed_set(Eo *obj, double speed);
 
 /**
  * @brief Control the audio volume.
@@ -134,16 +120,21 @@ EOAPI void efl_player_audio_volume_set(double volume);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_audio_volume_get(void);
+EOAPI double efl_player_audio_volume_get(const Eo *obj);
 
 /**
- * @brief This property controls the audio mute state.
+ * @brief Control the audio volume.
  *
- * @param[in] mute The mute state. True or false.
+ * Controls the audio volume of the stream being played. This has nothing to do
+ * with the system volume. This volume will be multiplied by the system volume.
+ * e.g.: if the current volume level is 0.5, and the system volume is 50%, it
+ * will be 0.5 * 0.5 = 0.25.
+ *
+ * @param[in] volume The volume level
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_audio_mute_set(Eina_Bool mute);
+EOAPI void efl_player_audio_volume_set(Eo *obj, double volume);
 
 /**
  * @brief This property controls the audio mute state.
@@ -152,7 +143,16 @@ EOAPI void efl_player_audio_mute_set(Eina_Bool mute);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_audio_mute_get(void);
+EOAPI Eina_Bool efl_player_audio_mute_get(const Eo *obj);
+
+/**
+ * @brief This property controls the audio mute state.
+ *
+ * @param[in] mute The mute state. True or false.
+ *
+ * @ingroup Efl_Player
+ */
+EOAPI void efl_player_audio_mute_set(Eo *obj, Eina_Bool mute);
 
 /**
  * @brief Get the length of play for the media file.
@@ -161,7 +161,7 @@ EOAPI Eina_Bool efl_player_audio_mute_get(void);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_length_get(void);
+EOAPI double efl_player_length_get(const Eo *obj);
 
 /**
  * @brief Get whether the media file is seekable.
@@ -170,7 +170,7 @@ EOAPI double efl_player_length_get(void);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_seekable_get(void);
+EOAPI Eina_Bool efl_player_seekable_get(const Eo *obj);
 
 
 #endif
