@@ -17,7 +17,23 @@ typedef int Efl_Font_Size;
 #endif
 #define EFL_TEXT_PROPERTIES_INTERFACE efl_text_properties_interface_get()
 
-EAPI const Eo_Class *efl_text_properties_interface_get(void) EINA_CONST;
+EWAPI const Eo_Class *efl_text_properties_interface_get(void);
+
+/**
+ * @brief Retrieve the font family and size in use on a given text object.
+ *
+ * This function allows the font name and size of a text object to be queried.
+ * Be aware that the font name string is still owned by Evas and should not
+ * have free() called on it by the caller of the function.
+ *
+ * See also @ref efl_text_properties_font_set.
+ *
+ * @param[out] font The font family name or filename.
+ * @param[out] size The font size, in points.
+ *
+ * @ingroup Efl_Text_Properties
+ */
+EOAPI void efl_text_properties_font_get(const Eo *obj, const char **font, Efl_Font_Size *size);
 
 /**
  * @brief Set the font family or filename, and size on a given text object.
@@ -36,23 +52,18 @@ EAPI const Eo_Class *efl_text_properties_interface_get(void) EINA_CONST;
  *
  * @ingroup Efl_Text_Properties
  */
-EOAPI void efl_text_properties_font_set(const char *font, Efl_Font_Size size);
+EOAPI void efl_text_properties_font_set(Eo *obj, const char *font, Efl_Font_Size size);
 
 /**
- * @brief Retrieve the font family and size in use on a given text object.
+ * @brief Get the font file's path which is being used on a given text object.
  *
- * This function allows the font name and size of a text object to be queried.
- * Be aware that the font name string is still owned by Evas and should not
- * have free() called on it by the caller of the function.
+ * See @ref efl_text_properties_font_get for more details.
  *
- * See also @ref efl_text_properties_font_set.
- *
- * @param[out] font The font family name or filename.
- * @param[out] size The font size, in points.
+ * @return The font file's path.
  *
  * @ingroup Efl_Text_Properties
  */
-EOAPI void efl_text_properties_font_get(const char **font, Efl_Font_Size *size);
+EOAPI const char *efl_text_properties_font_source_get(const Eo *obj);
 
 /**
  * @brief Set the font (source) file to be used on a given text object.
@@ -67,18 +78,7 @@ EOAPI void efl_text_properties_font_get(const char **font, Efl_Font_Size *size);
  *
  * @ingroup Efl_Text_Properties
  */
-EOAPI void efl_text_properties_font_source_set(const char *font_source);
-
-/**
- * @brief Get the font file's path which is being used on a given text object.
- *
- * See @ref efl_text_properties_font_get for more details.
- *
- * @return The font file's path.
- *
- * @ingroup Efl_Text_Properties
- */
-EOAPI const char *efl_text_properties_font_source_get(void);
+EOAPI void efl_text_properties_font_source_set(Eo *obj, const char *font_source);
 
 
 #endif
