@@ -13,15 +13,27 @@ typedef Eo Eldbus_Model_Arguments;
 
 
 #endif
+/** Eldbus model arguments class
+ *
+ * @ingroup Eldbus_Model_Arguments
+ */
 #define ELDBUS_MODEL_ARGUMENTS_CLASS eldbus_model_arguments_class_get()
 
-EAPI const Eo_Class *eldbus_model_arguments_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *eldbus_model_arguments_class_get(void);
 
-EOAPI const char *eldbus_model_arguments_name_get(void);
+/**
+ * @brief Name of the argument
+ *
+ * @return Argument name
+ *
+ * @ingroup Eldbus_Model_Arguments
+ */
+EOAPI const char *eldbus_model_arguments_name_get(const Eo *obj);
 
 /**
  * @brief Custom Eldbus_Model_Arguments constructor.
  *
+ * @param[in] proxy Eldbus proxy
  * @param[in] name Name
  * @param[in] arguments The introspected arguments
  *
@@ -29,7 +41,7 @@ EOAPI const char *eldbus_model_arguments_name_get(void);
  *
  * @ingroup Eldbus_Model_Arguments
  */
-EOAPI void eldbus_model_arguments_constructor(Eldbus_Proxy *proxy, const char *name, const Eina_List *arguments);
+EOAPI void eldbus_model_arguments_constructor(Eo *obj, Eldbus_Proxy *proxy, const char *name, const Eina_List *arguments);
 
 
 #endif
