@@ -15,11 +15,11 @@ typedef Eo Efl_VG_Container;
 #endif
 #define EFL_VG_CONTAINER_CLASS efl_vg_container_class_get()
 
-EAPI const Eo_Class *efl_vg_container_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *efl_vg_container_class_get(void);
 
-EOAPI Efl_VG_Base *efl_vg_container_child_get(const char *name);
+EOAPI Efl_VG *efl_vg_container_child_get(Eo *obj, const char *name);
 
-EOAPI Eina_Iterator *efl_vg_container_children_get(void);
+EOAPI Eina_Iterator *efl_vg_container_children_get(Eo *obj);
 
 
 #endif
