@@ -14,79 +14,6 @@ typedef Eo Evas_Canvas;
 
 #endif
 
-/**
- * @brief Sets the output framespace size of the render engine of the given
- * evas.
- *
- * The framespace size is used in the Wayland engines to denote space in the
- * viewport which is occupied by the window frame. This is mainly used in
- * ecore_evas to draw borders.
- *
- * The units used for @c w and @c h depend on the engine used by the evas.
- *
- * @param[in] x The left coordinate in output units, usually pixels.
- * @param[in] y The top coordinate in output units, usually pixels.
- * @param[in] w The width in output units, usually pixels.
- * @param[in] h The height in output units, usually pixels.
- *
- * @since 1.1
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_framespace_set(Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h);
-
-/**
- * @brief Get the render engine's output framespace coordinates in canvas
- * units.
- *
- * @param[out] x The left coordinate in output units, usually pixels.
- * @param[out] y The top coordinate in output units, usually pixels.
- * @param[out] w The width in output units, usually pixels.
- * @param[out] h The height in output units, usually pixels.
- *
- * @since 1.1
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_framespace_get(const Evas_Canvas *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
-
-/**
- * @brief Sets the output viewport of the given evas in evas units.
- *
- * The output viewport is the area of the evas that will be visible to the
- * viewer.  The viewport will be stretched to fit the output target of the evas
- * when rendering is performed.
- *
- * @note The coordinate values do not have to map 1-to-1 with the output
- * target. However, it is generally advised that it is done for ease of use.
- *
- * @param[in] x The top-left corner x value of the viewport.
- * @param[in] y The top-left corner y value of the viewport.
- * @param[in] w The width of the viewport.  Must be greater than 0.
- * @param[in] h The height of the viewport.  Must be greater than 0.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_viewport_set(Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h);
-
-/**
- * @brief Get the render engine's output viewport coordinates in canvas units.
- *
- * Calling this function writes the current canvas output viewport size and
- * location values into the variables pointed to by @c x, @c y, @c w and @c h.
- *  On success the variables have the output location and size values written
- * to them in canvas units. Any of @c x, @c y, @c w or @c h that are @c null
- * will not be written to. If @c e is invalid, the results are undefined.
- *
- * @param[out] x The top-left corner x value of the viewport.
- * @param[out] y The top-left corner y value of the viewport.
- * @param[out] w The width of the viewport.  Must be greater than 0.
- * @param[out] h The height of the viewport.  Must be greater than 0.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_viewport_get(const Evas_Canvas *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
-
 /**
  * @brief Set the image cache.
  *
@@ -122,7 +49,7 @@ EAPI int evas_image_cache_get(const Evas_Canvas *obj);
  *
  * @ingroup Evas_Canvas
  */
-EAPI void evas_event_default_flags_set(Evas_Canvas *obj, Evas_Event_Flags flags);
+EAPI void evas_event_default_flags_set(Evas_Canvas *obj, Efl_Event_Flags flags);
 
 /**
  * @brief Get the default set of flags an event begins with
@@ -135,32 +62,7 @@ EAPI void evas_event_default_flags_set(Evas_Canvas *obj, Evas_Event_Flags flags)
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Event_Flags evas_event_default_flags_get(const Evas_Canvas *obj);
-
-/**
- * @brief Sets the output engine for the given evas.
- *
- * Once the output engine for an evas is set, any attempt to change it  will be
- * ignored. The value for @c render_method can be found using @ref
- * evas_render_method_lookup.
- *
- * @note it is mandatory that one calls @ref evas_init before setting the
- * output method.
- *
- * @param[in] render_method The numeric engine value to use.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_method_set(Evas_Canvas *obj, int render_method);
-
-/**
- * @brief Retrieves the number of the output engine used for the given evas.
- *
- * @return The numeric engine value to use.
- *
- * @ingroup Evas_Canvas
- */
-EAPI int evas_output_method_get(const Evas_Canvas *obj);
+EAPI Efl_Event_Flags evas_event_default_flags_get(const Evas_Canvas *obj);
 
 /**
  * @brief Changes the size of font cache of the given evas.
@@ -180,37 +82,6 @@ EAPI void evas_font_cache_set(Evas_Canvas *obj, int size);
  */
 EAPI int evas_font_cache_get(const Evas_Canvas *obj);
 
-/**
- * @brief Sets the output size of the render engine of the given evas.
- *
- * The evas will render to a rectangle of the given size once this function is
- * called.  The output size is independent of the viewport size. The viewport
- * will be stretched to fill the given rectangle.
- *
- * The units used for @c w and @c h depend on the engine used by the evas.
- *
- * @param[in] w The width in output units, usually pixels.
- * @param[in] h The height in output units, usually pixels.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_size_set(Evas_Canvas *obj, int w, int h);
-
-/**
- * @brief Retrieve the output size of the render engine of the given evas.
- *
- * The output size is given in whatever the output units are for the engine.
- *
- * If either @c w or @c h is @c null, then it is ignored.  If @c e is invalid,
- * the returned results are undefined.
- *
- * @param[out] w The width in output units, usually pixels.
- * @param[out] h The height in output units, usually pixels.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_output_size_get(const Evas_Canvas *obj, int *w, int *h);
-
 /**
  * @brief Attaches a specific pointer to the evas for fetching later.
  *
@@ -309,7 +180,7 @@ EAPI Evas_Engine_Info *evas_engine_info_get(const Evas_Canvas *obj);
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Object *evas_focus_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_focus_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Get the highest (stacked) Evas object on the canvas @c e.
@@ -327,7 +198,7 @@ EAPI Evas_Object *evas_focus_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Object *evas_object_top_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_top_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Returns a handle to the list of lock keys registered in the canvas
@@ -417,9 +288,8 @@ EAPI void evas_pointer_output_xy_get(const Evas_Canvas *obj, int *x, int *y);
  * @brief Returns whether the mouse pointer is logically inside the canvas.
  *
  * When this function is called it will return a value of either @c false or
- * @c true, depending on if @ref evas_event_feed_mouse_in or
- * @ref evas_event_feed_mouse_out have been called to feed in a  mouse enter
- * event into the canvas.
+ * @c true, depending on if event_feed_mouse_in or event_feed_mouse_out have
+ * been called to feed in a  mouse enter event into the canvas.
  *
  * A return value of @c true indicates the mouse is logically inside the
  * canvas, and @c false implies it is logically outside the canvas.
@@ -468,7 +338,7 @@ EAPI Eina_Bool evas_image_max_size_get(const Evas_Canvas *obj, int *maxw, int *m
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Object *evas_object_bottom_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_bottom_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Returns a handle to the list of modifier keys registered in the
@@ -496,8 +366,7 @@ EAPI const Evas_Modifier *evas_key_modifier_get(const Evas_Canvas *obj) EINA_WAR
  * excess of any host system's pointing device abilities.
  *
  * A canvas by default begins with no mouse buttons being pressed and only
- * calls to @ref evas_event_feed_mouse_down and @ref evas_event_feed_mouse_up
- * will alter that.
+ * pointer move events can alter that.
  *
  * The least significant bit corresponds to the first mouse button (button 1)
  * and the most significant bit corresponds to the last mouse button (button
@@ -509,7 +378,7 @@ EAPI const Evas_Modifier *evas_key_modifier_get(const Evas_Canvas *obj) EINA_WAR
  *
  * @ingroup Evas_Canvas
  */
-EAPI int evas_pointer_button_down_mask_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
+EAPI unsigned int evas_pointer_button_down_mask_get(const Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Retrieve a list of Evas objects lying over a given position in a
@@ -520,27 +389,13 @@ EAPI int evas_pointer_button_down_mask_get(const Evas_Canvas *obj) EINA_WARN_UNU
  * enter the smart objects. It will not append to the list pass events as
  * hidden objects. Call eina_list_free on the returned list after usage.
  *
+ * @param[in] stop An Evas Object where to stop searching.
  * @param[in] x The horizontal coordinate of the position.
  * @param[in] y The vertical coordinate of the position.
  *
  * @ingroup Evas_Canvas
  */
-EAPI Eina_List *evas_tree_objects_at_xy_get(Evas_Canvas *obj, Evas_Object *stop, int x, int y) EINA_WARN_UNUSED_RESULT;
-
-/**
- * @brief Mouse wheel event feed.
- *
- * This function will set some evas properties that is necessary when the mouse
- * wheel is scrolled up or down. It prepares information to  be treated by the
- * callback function.
- *
- * @param[in] z How much mouse wheel was scrolled up or down.
- * @param[in] timestamp The timestamp of the mouse up event.
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_wheel(Evas_Canvas *obj, int direction, int z, unsigned int timestamp, const void *data);
+EAPI Eina_List *evas_tree_objects_at_xy_get(Evas_Canvas *obj, Efl_Canvas_Object *stop, int x, int y) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Enables or turns on programmatically the lock key with name
@@ -558,22 +413,6 @@ EAPI void evas_event_feed_mouse_wheel(Evas_Canvas *obj, int direction, int z, un
  */
 EAPI void evas_key_lock_on(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONNULL(2);
 
-/**
- * @brief Key down event feed.
- *
- * This function will set some evas properties that is necessary when a key is
- * pressed. It prepares information to be treated by the callback function.
- *
- * @param[in] key The key pressed.
- * @param[in] string A string.
- * @param[in] compose The compose string.
- * @param[in] timestamp Timestamp of the mouse up event.
- * @param[in] data Data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_key_down(Evas_Canvas *obj, const char *keyname, const char *key, const char *string, const char *compose, unsigned int timestamp, const void *data);
-
 /**
  * @brief Creates a bit mask from the @c keyname modifier key. Values returned
  * from different calls to it may be ORed together, naturally.
@@ -634,63 +473,6 @@ EAPI void evas_key_modifier_add(Evas_Canvas *obj, const char *keyname) EINA_ARG_
  */
 EAPI void evas_key_modifier_off(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONNULL(2);
 
-/**
- * @brief Hold event feed.
- *
- * This function makes the object to stop sending events.
- *
- * @param[in] timestamp The timestamp of the mouse up event.
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_hold(Evas_Canvas *obj, int hold, unsigned int timestamp, const void *data);
-
-/**
- * @brief Mouse move event feed.
- *
- * This function will set some evas properties that is necessary when the mouse
- * is moved from its last position. It prepares information to be treated by
- * the callback function.
- *
- * @param[in] y The vertical position of the mouse pointer.
- * @param[in] timestamp The timestamp of the mouse up event.
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_move(Evas_Canvas *obj, int x, int y, unsigned int timestamp, const void *data);
-
-/**
- * @brief Key up event feed.
- *
- * This function will set some evas properties that is necessary when a key is
- * released. It prepares information to be treated by the callback function.
- *
- * @param[in] key The key released.
- * @param[in] string A string.
- * @param[in] compose Compose.
- * @param[in] timestamp Timestamp of the mouse up event.
- * @param[in] data Data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_key_up(Evas_Canvas *obj, const char *keyname, const char *key, const char *string, const char *compose, unsigned int timestamp, const void *data);
-
-/**
- * @brief Mouse out event feed.
- *
- * This function will set some evas properties that is necessar when the mouse
- * out event happens. It prepares information to be treated by the callback
- * function.
- *
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_out(Evas_Canvas *obj, unsigned int timestamp, const void *data);
-EAPI void evas_event_input_multi_move(Evas_Canvas *obj, int d, int x, int y, double rad, double radx, double rady, double pres, double ang, double fx, double fy, unsigned int timestamp, const void *data);
-
 /**
  * @brief Retrieve a list of Evas objects lying over a given position in a
  * canvas.
@@ -703,6 +485,7 @@ EAPI void evas_event_input_multi_move(Evas_Canvas *obj, int d, int x, int y, dou
  * @warning This function will skip objects parented by smart objects, acting
  * only on the ones at the "top level", with regard to object parenting.
  *
+ * @param[in] x The horizontal coordinate of the position.
  * @param[in] y The vertical coordinate of the position.
  * @param[in] include_pass_events_objects Boolean flag to include or not
  * objects which pass events in this calculation.
@@ -714,8 +497,6 @@ EAPI void evas_event_input_multi_move(Evas_Canvas *obj, int d, int x, int y, dou
  * @ingroup Evas_Canvas
  */
 EAPI Eina_List *evas_objects_at_xy_get(const Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
-EAPI void evas_event_input_multi_up(Evas_Canvas *obj, int d, int x, int y, double rad, double radx, double rady, double pres, double ang, double fx, double fy, Evas_Button_Flags flags, unsigned int timestamp, const void *data);
-EAPI void evas_event_feed_multi_down(Evas_Canvas *obj, int d, int x, int y, double rad, double radx, double rady, double pres, double ang, double fx, double fy, Evas_Button_Flags flags, unsigned int timestamp, const void *data);
 
 /**
  * @brief Render the given Evas canvas asynchronously.
@@ -779,26 +560,6 @@ EAPI Eina_List *evas_render2_updates(Evas_Canvas *obj) EINA_WARN_UNUSED_RESULT;
  */
 EAPI void evas_focus_out(Evas_Canvas *obj);
 
-/**
- * @brief Mouse move event feed from input.
- *
- * Similar to the @ref evas_event_feed_mouse_move, this function will inform
- * Evas about mouse move events which were received by the input system,
- * relative to the 0,0 of the window, not to the canvas 0,0. It will take care
- * of doing any special transformation like adding the framespace offset to the
- * mouse event.
- *
- * @param[in] y The vertical position of the mouse pointer relative to the 0,0
- * of the window/surface.
- * @param[in] timestamp The timestamp of the mouse move event.
- * @param[in] data The data for canvas.
- *
- * @since 1.8
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_input_mouse_move(Evas_Canvas *obj, int x, int y, unsigned int timestamp, const void *data);
-
 /**
  * @brief Update the canvas internal objects but not triggering immediate
  * renderization.
@@ -822,7 +583,6 @@ EAPI void evas_norender(Evas_Canvas *obj);
  * @ingroup Evas_Canvas
  */
 EAPI unsigned int evas_touch_point_list_count(Evas_Canvas *obj);
-EAPI void evas_event_input_multi_down(Evas_Canvas *obj, int d, int x, int y, double rad, double radx, double rady, double pres, double ang, double fx, double fy, Evas_Button_Flags flags, unsigned int timestamp, const void *data);
 
 /**
  * @brief Pop the nochange flag down 1.
@@ -897,6 +657,7 @@ EAPI Eina_Bool evas_font_hinting_can_hint(const Evas_Canvas *obj, Evas_Font_Hint
  * @warning This function will skip objects parented by smart objects, acting
  * only on the ones at the "top level", with regard to object parenting.
  *
+ * @param[in] x The horizontal coordinate of the position.
  * @param[in] y The vertical coordinate of the position.
  * @param[in] include_pass_events_objects Boolean flag to include or not
  * objects which pass events in this calculation.
@@ -908,7 +669,7 @@ EAPI Eina_Bool evas_font_hinting_can_hint(const Evas_Canvas *obj, Evas_Font_Hint
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Object *evas_object_top_at_xy_get(const Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_top_at_xy_get(const Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Enables or turns on programmatically the modifier key with name
@@ -925,50 +686,6 @@ EAPI Evas_Object *evas_object_top_at_xy_get(const Evas_Canvas *obj, Evas_Coord x
  */
 EAPI void evas_key_modifier_on(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONNULL(2);
 
-/**
- * @brief Mouse up event feed.
- *
- * This function will set some evas properties that is necessary when the mouse
- * button is released. It prepares information to be treated by the callback
- * function.
- *
- * @param[in] flags Evas button flags.
- * @param[in] timestamp The timestamp of the mouse up event.
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_up(Evas_Canvas *obj, int b, Evas_Button_Flags flags, unsigned int timestamp, const void *data);
-
-/**
- * @brief Mouse down event feed.
- *
- * This function will set some evas properties that is necessary when the mouse
- * button is pressed. It prepares information to be treated by the callback
- * function.
- *
- * @param[in] flags Evas button flags.
- * @param[in] timestamp The timestamp of the mouse up event.
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_down(Evas_Canvas *obj, int b, Evas_Button_Flags flags, unsigned int timestamp, const void *data);
-
-/**
- * @brief Re feed event.
- *
- * This function re-feeds the event pointed by event_copy.
- *
- * This function call evas_event_feed_* functions, so it can cause havoc if not
- * used wisely. Please use it responsibly.
- *
- * @param[in] event_type Event type.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_refeed_event(Evas_Canvas *obj, void *event_copy, Evas_Callback_Type event_type);
-
 /**
  * @brief List of available font descriptions known or found by this evas.
  *
@@ -999,7 +716,7 @@ EAPI Eina_List *evas_objects_in_rectangle_get(const Evas_Canvas *obj, Evas_Coord
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Object *evas_object_name_find(const Evas_Canvas *obj, const char *name) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_name_find(const Evas_Canvas *obj, const char *name) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Appends a font path to the list of font paths used by the given evas.
@@ -1044,6 +761,7 @@ EAPI void evas_smart_objects_calculate(Evas_Canvas *obj);
  * Touch point's coordinates is updated whenever moving that point on the
  * canvas.
  *
+ * @param[in] n The number of the touched point (0 being the first).
  * @param[out] x The pointer to a Evas_Coord to be filled in.
  * @param[out] y The pointer to a Evas_Coord to be filled in.
  *
@@ -1070,6 +788,7 @@ EAPI void evas_key_lock_del(Evas_Canvas *obj, const char *keyname) EINA_ARG_NONN
  * @note All newly created Evas rectangles get the default color values of 255
  * 255 255 255 (opaque white).
  *
+ * @param[in] x The rectangle's left position.
  * @param[in] y The rectangle's top position.
  * @param[in] w The rectangle's width.
  * @param[in] h The rectangle's height.
@@ -1112,7 +831,6 @@ EAPI void evas_image_cache_reload(Evas_Canvas *obj);
  * @ingroup Evas_Canvas
  */
 EAPI int evas_coord_world_x_to_screen(const Evas_Canvas *obj, Evas_Coord x) EINA_WARN_UNUSED_RESULT;
-EAPI void evas_event_feed_multi_move(Evas_Canvas *obj, int d, int x, int y, double rad, double radx, double rady, double pres, double ang, double fx, double fy, unsigned int timestamp, const void *data);
 
 /**
  * @brief Force immediate renderization of the given Evas canvas.
@@ -1228,6 +946,7 @@ EAPI void evas_focus_in(Evas_Canvas *obj);
  * you want to re-render it afterwards expecting new contents, you have to add
  * "damage" regions yourself (see @ref evas_damage_rectangle_add).
  *
+ * @param[in] x The rectangle's top left corner's horizontal coordinate.
  * @param[in] y The rectangle's top left corner's vertical coordinate.
  * @param[in] w The rectangle's width.
  * @param[in] h The rectangle's height.
@@ -1250,19 +969,6 @@ EAPI void evas_obscured_rectangle_add(Evas_Canvas *obj, int x, int y, int w, int
  */
 EAPI void evas_render_dump(Evas_Canvas *obj);
 
-/**
- * @brief Mouse in event feed.
- *
- * This function will set some evas properties that is necessary when the mouse
- * in event happens. It prepares information to be treated by the callback
- * function.
- *
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_in(Evas_Canvas *obj, unsigned int timestamp, const void *data);
-
 /**
  * @brief Retrieve the Evas object stacked at the top of a given rectangular
  * region in a canvas
@@ -1275,6 +981,8 @@ EAPI void evas_event_feed_mouse_in(Evas_Canvas *obj, unsigned int timestamp, con
  * @warning This function will skip objects parented by smart objects, acting
  * only on the ones at the "top level", with regard to object parenting.
  *
+ * @param[in] x The top left corner's horizontal coordinate for the rectangular
+ * region.
  * @param[in] y The top left corner's vertical coordinate for the rectangular
  * region.
  * @param[in] w The width of the rectangular region.
@@ -1289,14 +997,13 @@ EAPI void evas_event_feed_mouse_in(Evas_Canvas *obj, unsigned int timestamp, con
  *
  * @ingroup Evas_Canvas
  */
-EAPI Evas_Object *evas_object_top_in_rectangle_get(const Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
+EAPI Efl_Canvas_Object *evas_object_top_in_rectangle_get(const Evas_Canvas *obj, Evas_Coord x, Evas_Coord y, Evas_Coord w, Evas_Coord h, Eina_Bool include_pass_events_objects, Eina_Bool include_hidden_objects) EINA_WARN_UNUSED_RESULT;
 
 /** Force renderization of the given canvas.
  *
  * @ingroup Evas_Canvas
  */
 EAPI void evas_render(Evas_Canvas *obj);
-EAPI void evas_event_feed_multi_up(Evas_Canvas *obj, int d, int x, int y, double rad, double radx, double rady, double pres, double ang, double fx, double fy, Evas_Button_Flags flags, unsigned int timestamp, const void *data);
 
 /**
  * @brief Prepends a font path to the list of font paths used by the given
@@ -1327,18 +1034,6 @@ EAPI void evas_font_path_prepend(Evas_Canvas *obj, const char *path) EINA_ARG_NO
  */
 EAPI void evas_obscured_clear(Evas_Canvas *obj);
 
-/**
- * @brief Mouse cancel event feed.
- *
- * This function will call @ref evas_event_feed_mouse_up when a mouse cancel
- * event happens.
- *
- * @param[in] data The data for canvas.
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_mouse_cancel(Evas_Canvas *obj, unsigned int timestamp, const void *data);
-
 /**
  * @brief Convert/scale an output screen coordinate into canvas coordinates.
  *
@@ -1407,61 +1102,4 @@ EAPI void evas_render_idle_flush(Evas_Canvas *obj);
  */
 EAPI int evas_coord_world_y_to_screen(const Evas_Canvas *obj, Evas_Coord y) EINA_WARN_UNUSED_RESULT;
 
-/**
- * @brief Key down event feed with keycode.
- *
- * This function will set some evas properties that is necessary when a key is
- * pressed. It prepares information to be treated by the callback function.
- *
- * @param[in] key The key released.
- * @param[in] string A string.
- * @param[in] compose Compose.
- * @param[in] timestamp Timestamp of the mouse up event.
- * @param[in] data Data for canvas.
- * @param[in] keycode Key scan code numeric value for canvas.
- *
- * @since 1.10
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_key_down_with_keycode(Evas_Canvas *obj, const char *keyname, const char *key, const char *string, const char *compose, unsigned int timestamp, const void *data, unsigned int keycode);
-
-/**
- * @brief Key up event feed with keycode.
- *
- * This function will set some evas properties that is necessary when a key is
- * released. It prepares information to be treated by the callback function.
- *
- * @param[in] key The key released.
- * @param[in] string A string.
- * @param[in] compose Compose.
- * @param[in] timestamp Timestamp of the mouse up event.
- * @param[in] data Data for canvas.
- * @param[in] keycode Key scan code numeric value for canvas.
- *
- * @since 1.10
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_key_up_with_keycode(Evas_Canvas *obj, const char *keyname, const char *key, const char *string, const char *compose, unsigned int timestamp, const void *data, unsigned int keycode);
-
-/**
- * @brief Input device axis update event feed.
- *
- * This function will set some evas properties that is necessary when an e.g.
- * stylus axis is updated. It prepares information to be treated by the
- * callback function.
- *
- * @param[in] device System-provided device identifier.
- * @param[in] toolid Type of tool currently being used.
- * @param[in] naxes Number of elements in the \p axis array.
- * @param[in] axis Array containing the current value of all updated axes.
- * @param[in] data Data for canvas.
- *
- * @since 1.13
- *
- * @ingroup Evas_Canvas
- */
-EAPI void evas_event_feed_axis_update(Evas_Canvas *obj, unsigned int timestamp, int device, int toolid, int naxes, const Evas_Axis *axis, const void *data);
-
 #endif
