@@ -15,27 +15,27 @@ typedef Eo Evas_Canvas3D_Mesh;
 #endif
 #define EVAS_CANVAS3D_MESH_CLASS evas_canvas3d_mesh_class_get()
 
-EAPI const Eo_Class *evas_canvas3d_mesh_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *evas_canvas3d_mesh_class_get(void);
 
 /**
- * @brief Set the shade mode of the given mesh.
+ * @brief Set the shader mode of the given mesh.
  *
- * Default shade mode is EVAS_CANVAS3D_SHADE_MODE_VERTEX_COLOR.
+ * Default shader mode is EVAS_CANVAS3D_SHADER_MODE_VERTEX_COLOR.
  *
- * @param[in] mode The shade mode.
+ * @param[in] mode The shader mode.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_shade_mode_set(Evas_Canvas3D_Shade_Mode mode);
+EOAPI void evas_canvas3d_mesh_shader_mode_set(Eo *obj, Evas_Canvas3D_Shader_Mode mode);
 
 /**
- * @brief Get the shade mode of the given mesh.
+ * @brief Get the shader mode of the given mesh.
  *
- * @return The shade mode.
+ * @return The shader mode.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Evas_Canvas3D_Shade_Mode evas_canvas3d_mesh_shade_mode_get(void);
+EOAPI Evas_Canvas3D_Shader_Mode evas_canvas3d_mesh_shader_mode_get(const Eo *obj);
 
 /**
  * @brief Set posibility color picking.
@@ -44,7 +44,7 @@ EOAPI Evas_Canvas3D_Shade_Mode evas_canvas3d_mesh_shade_mode_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_color_pick_enable_set(Eina_Bool enabled);
+EOAPI void evas_canvas3d_mesh_color_pick_enable_set(Eo *obj, Eina_Bool enabled);
 
 /**
  * @brief Get status of color picking of the mesh.
@@ -53,7 +53,7 @@ EOAPI void evas_canvas3d_mesh_color_pick_enable_set(Eina_Bool enabled);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Eina_Bool evas_canvas3d_mesh_color_pick_enable_get(void);
+EOAPI Eina_Bool evas_canvas3d_mesh_color_pick_enable_get(const Eo *obj);
 
 /**
  * @brief Set the vertex count of the given mesh.
@@ -68,7 +68,7 @@ EOAPI Eina_Bool evas_canvas3d_mesh_color_pick_enable_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_vertex_count_set(unsigned int count);
+EOAPI void evas_canvas3d_mesh_vertex_count_set(Eo *obj, unsigned int count);
 
 /**
  * @brief Get the vertex count of the given mesh.
@@ -77,7 +77,7 @@ EOAPI void evas_canvas3d_mesh_vertex_count_set(unsigned int count);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI unsigned int evas_canvas3d_mesh_vertex_count_get(void);
+EOAPI unsigned int evas_canvas3d_mesh_vertex_count_get(const Eo *obj);
 
 /**
  * @brief Enable or disable fog effect for given mesh.
@@ -88,7 +88,7 @@ EOAPI unsigned int evas_canvas3d_mesh_vertex_count_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_fog_enable_set(Eina_Bool enabled);
+EOAPI void evas_canvas3d_mesh_fog_enable_set(Eo *obj, Eina_Bool enabled);
 
 /**
  * @brief Get the enable status of fog effect for given mesh.
@@ -97,7 +97,7 @@ EOAPI void evas_canvas3d_mesh_fog_enable_set(Eina_Bool enabled);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Eina_Bool evas_canvas3d_mesh_fog_enable_get(void);
+EOAPI Eina_Bool evas_canvas3d_mesh_fog_enable_get(const Eo *obj);
 
 /**
  * @brief Get the enable status of alpha test for given mesh.
@@ -108,7 +108,7 @@ EOAPI Eina_Bool evas_canvas3d_mesh_fog_enable_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_alpha_test_enable_set(Eina_Bool enabled);
+EOAPI void evas_canvas3d_mesh_alpha_test_enable_set(Eo *obj, Eina_Bool enabled);
 
 /**
  * @brief Get the enable status of alpha test for given mesh.
@@ -117,7 +117,7 @@ EOAPI void evas_canvas3d_mesh_alpha_test_enable_set(Eina_Bool enabled);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Eina_Bool evas_canvas3d_mesh_alpha_test_enable_get(void);
+EOAPI Eina_Bool evas_canvas3d_mesh_alpha_test_enable_get(const Eo *obj);
 
 /**
  * @brief Set the alpha func.
@@ -132,7 +132,7 @@ EOAPI Eina_Bool evas_canvas3d_mesh_alpha_test_enable_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_alpha_func_set(Evas_Canvas3D_Comparison comparison_func, Evas_Real ref_value);
+EOAPI void evas_canvas3d_mesh_alpha_func_set(Eo *obj, Evas_Canvas3D_Comparison comparison_func, Evas_Real ref_value);
 
 /**
  * @brief Get the reference value and the comparison function for alpha
@@ -144,7 +144,7 @@ EOAPI void evas_canvas3d_mesh_alpha_func_set(Evas_Canvas3D_Comparison comparison
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_alpha_func_get(Evas_Canvas3D_Comparison *comparison_func, Evas_Real *ref_value);
+EOAPI void evas_canvas3d_mesh_alpha_func_get(const Eo *obj, Evas_Canvas3D_Comparison *comparison_func, Evas_Real *ref_value);
 
 /**
  * @brief Enable or disable blending for given mesh.
@@ -153,7 +153,7 @@ EOAPI void evas_canvas3d_mesh_alpha_func_get(Evas_Canvas3D_Comparison *compariso
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_blending_enable_set(Eina_Bool blending);
+EOAPI void evas_canvas3d_mesh_blending_enable_set(Eo *obj, Eina_Bool blending);
 
 /**
  * @brief Get whether blending is enabled for the mesh.
@@ -162,7 +162,7 @@ EOAPI void evas_canvas3d_mesh_blending_enable_set(Eina_Bool blending);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Eina_Bool evas_canvas3d_mesh_blending_enable_get(void);
+EOAPI Eina_Bool evas_canvas3d_mesh_blending_enable_get(const Eo *obj);
 
 /**
  * @brief Set the material of the key frame of the given mesh.
@@ -175,7 +175,7 @@ EOAPI Eina_Bool evas_canvas3d_mesh_blending_enable_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_frame_material_set(int frame, Evas_Canvas3D_Material *material);
+EOAPI void evas_canvas3d_mesh_frame_material_set(Eo *obj, int frame, Evas_Canvas3D_Material *material);
 
 /**
  * @brief Get the material of the key frame of the given mesh.
@@ -186,7 +186,7 @@ EOAPI void evas_canvas3d_mesh_frame_material_set(int frame, Evas_Canvas3D_Materi
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Evas_Canvas3D_Material *evas_canvas3d_mesh_frame_material_get(int frame);
+EOAPI Evas_Canvas3D_Material *evas_canvas3d_mesh_frame_material_get(const Eo *obj, int frame);
 
 /**
  * @brief Set the vertex assembly of the given mesh.
@@ -200,7 +200,7 @@ EOAPI Evas_Canvas3D_Material *evas_canvas3d_mesh_frame_material_get(int frame);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_vertex_assembly_set(Evas_Canvas3D_Vertex_Assembly assembly);
+EOAPI void evas_canvas3d_mesh_vertex_assembly_set(Eo *obj, Evas_Canvas3D_Vertex_Assembly assembly);
 
 /**
  * @brief Get the vertex assembly of the given mesh.
@@ -209,7 +209,7 @@ EOAPI void evas_canvas3d_mesh_vertex_assembly_set(Evas_Canvas3D_Vertex_Assembly
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Evas_Canvas3D_Vertex_Assembly evas_canvas3d_mesh_vertex_assembly_get(void);
+EOAPI Evas_Canvas3D_Vertex_Assembly evas_canvas3d_mesh_vertex_assembly_get(const Eo *obj);
 
 /**
  * @brief Set the shadow edges blur parameters.
@@ -222,7 +222,7 @@ EOAPI Evas_Canvas3D_Vertex_Assembly evas_canvas3d_mesh_vertex_assembly_get(void)
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_shadows_edges_filtering_set(int blur_level, Evas_Real edges_size);
+EOAPI void evas_canvas3d_mesh_shadows_edges_filtering_set(Eo *obj, int blur_level, Evas_Real edges_size);
 
 /**
  * @brief Get the shadow edges blur parameters.
@@ -232,7 +232,7 @@ EOAPI void evas_canvas3d_mesh_shadows_edges_filtering_set(int blur_level, Evas_R
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_shadows_edges_filtering_get(int *blur_level, Evas_Real *edges_size);
+EOAPI void evas_canvas3d_mesh_shadows_edges_filtering_get(const Eo *obj, int *blur_level, Evas_Real *edges_size);
 
 /**
  * @brief Set offset shadow toward object.
@@ -241,7 +241,7 @@ EOAPI void evas_canvas3d_mesh_shadows_edges_filtering_get(int *blur_level, Evas_
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_shadows_constant_bias_set(Evas_Real bias);
+EOAPI void evas_canvas3d_mesh_shadows_constant_bias_set(Eo *obj, Evas_Real bias);
 
 /**
  * @brief Get offset shadow toward object.
@@ -250,7 +250,29 @@ EOAPI void evas_canvas3d_mesh_shadows_constant_bias_set(Evas_Real bias);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Evas_Real evas_canvas3d_mesh_shadows_constant_bias_get(void);
+EOAPI Evas_Real evas_canvas3d_mesh_shadows_constant_bias_get(const Eo *obj);
+
+/**
+ * @brief Set LOD boundary distances.
+ *
+ * @param[in] near_lod up boundary
+ * @param[in] far_lod down boundary
+ *
+ * @ingroup Evas_Canvas3D_Mesh
+ */
+EOAPI void evas_canvas3d_mesh_lod_boundary_set(Eo *obj, Evas_Real near_lod, Evas_Real far_lod);
+
+/**
+ * @brief Get LOD boundary distances.
+ *
+ * See also @ref evas_canvas3d_mesh_lod_boundary_set.
+ *
+ * @param[out] near_lod up boundary
+ * @param[out] far_lod down boundary
+ *
+ * @ingroup Evas_Canvas3D_Mesh
+ */
+EOAPI void evas_canvas3d_mesh_lod_boundary_get(const Eo *obj, Evas_Real *near_lod, Evas_Real *far_lod);
 
 /**
  * @brief Set the vertex data of the key frame of the given mesh.
@@ -265,13 +287,14 @@ EOAPI Evas_Real evas_canvas3d_mesh_shadows_constant_bias_get(void);
  * See also @ref evas_canvas3d_mesh_frame_vertex_data_map,
  * @ref evas_canvas3d_mesh_frame_vertex_data_unmap.
  *
+ * @param[in] frame The number of the key frame.
  * @param[in] attrib Vertex attribute ID.
  * @param[in] stride Stride to go to the next vertex (in bytes).
  * @param[in] data Pointer to the vertex data buffer.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_frame_vertex_data_set(int frame, Evas_Canvas3D_Vertex_Attrib attrib, int stride, const void *data);
+EOAPI void evas_canvas3d_mesh_frame_vertex_data_set(Eo *obj, int frame, Evas_Canvas3D_Vertex_Attrib attrib, int stride, const void *data);
 
 /**
  * @brief Set the vertex data of the key frame of the given mesh by copying
@@ -283,13 +306,14 @@ EOAPI void evas_canvas3d_mesh_frame_vertex_data_set(int frame, Evas_Canvas3D_Ver
  *
  * See also @ref evas_canvas3d_mesh_frame_vertex_data_set.
  *
+ * @param[in] frame The number of the key frame.
  * @param[in] attrib Vertex attribute ID.
  * @param[in] stride Stride to go to the next vertex (in bytes).
  * @param[in] data Pointer to the vertex data buffer.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_frame_vertex_data_copy_set(int frame, Evas_Canvas3D_Vertex_Attrib attrib, int stride, const void *data);
+EOAPI void evas_canvas3d_mesh_frame_vertex_data_copy_set(Eo *obj, int frame, Evas_Canvas3D_Vertex_Attrib attrib, int stride, const void *data);
 
 /**
  * @brief Map the vertex buffer of the key frame of the given mesh.
@@ -301,24 +325,26 @@ EOAPI void evas_canvas3d_mesh_frame_vertex_data_copy_set(int frame, Evas_Canvas3
  * buffer will be returned. Otherwise, the returned pointer can differ every
  * time calling this function.
  *
+ * @param[in] frame The number of the key frame.
  * @param[in] attrib Vertex attribute ID.
  *
  * @return Starting address of the mapped vertex buffer.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void *evas_canvas3d_mesh_frame_vertex_data_map(int frame, Evas_Canvas3D_Vertex_Attrib attrib);
+EOAPI void *evas_canvas3d_mesh_frame_vertex_data_map(Eo *obj, int frame, Evas_Canvas3D_Vertex_Attrib attrib);
 
 /**
  * @brief Unmap the vertex buffer of the key frame of the given mesh.
  *
  * See also @ref evas_canvas3d_mesh_frame_vertex_data_map.
  *
+ * @param[in] frame The number of the key frame.
  * @param[in] attrib Vertex attribute ID.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_frame_vertex_data_unmap(int frame, Evas_Canvas3D_Vertex_Attrib attrib);
+EOAPI void evas_canvas3d_mesh_frame_vertex_data_unmap(Eo *obj, int frame, Evas_Canvas3D_Vertex_Attrib attrib);
 
 /**
  * @brief Get the vertex buffer stride of the key frame of the given mesh.
@@ -327,13 +353,14 @@ EOAPI void evas_canvas3d_mesh_frame_vertex_data_unmap(int frame, Evas_Canvas3D_V
  * the data was set with @ref evas_canvas3d_mesh_frame_vertex_data_set, the
  * original stride will be returned unchanged.
  *
+ * @param[in] frame The number of the key frame.
  * @param[in] attrib Vertex attribute ID.
  *
  * @return Stride to go to the next vertex (in bytes).
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI int evas_canvas3d_mesh_frame_vertex_stride_get(int frame, Evas_Canvas3D_Vertex_Attrib attrib);
+EOAPI int evas_canvas3d_mesh_frame_vertex_stride_get(const Eo *obj, int frame, Evas_Canvas3D_Vertex_Attrib attrib);
 
 /**
  * @brief Set the vertex index data of the given mesh.
@@ -343,22 +370,24 @@ EOAPI int evas_canvas3d_mesh_frame_vertex_stride_get(int frame, Evas_Canvas3D_Ve
  * @ref evas_canvas3d_mesh_index_data_copy_set. Further modifications should be
  * made within map/unmap pair.
  *
+ * @param[in] format Vertex index data format.
  * @param[in] count Vertex index count.
  * @param[in] indices Pointer to the index data.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_index_data_set(Evas_Canvas3D_Index_Format format, int count, const void *indices);
+EOAPI void evas_canvas3d_mesh_index_data_set(Eo *obj, Evas_Canvas3D_Index_Format format, int count, const void *indices);
 
 /**
  * @brief Get the vertex and index data of convex hull around the given mesh.
  *
+ * @param[in] frame The number of the key frame.
  * @param[in] vertex
  * @param[in] index
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_convex_hull_data_get(int frame, Eina_Inarray *vertex, Eina_Inarray *index);
+EOAPI void evas_canvas3d_mesh_convex_hull_data_get(Eo *obj, int frame, Eina_Inarray *vertex, Eina_Inarray *index);
 
 /**
  * @brief Set the vertex index data of the given mesh by copying from a buffer.
@@ -368,12 +397,13 @@ EOAPI void evas_canvas3d_mesh_convex_hull_data_get(int frame, Eina_Inarray *vert
  *
  * See also @ref evas_canvas3d_mesh_index_data_set.
  *
+ * @param[in] format Vertex index data format.
  * @param[in] count Vertex index count.
  * @param[in] indices Pointer to the index data.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_index_data_copy_set(Evas_Canvas3D_Index_Format format, int count, const void *indices);
+EOAPI void evas_canvas3d_mesh_index_data_copy_set(Eo *obj, Evas_Canvas3D_Index_Format format, int count, const void *indices);
 
 /**
  * @brief Get the format of the index data of the given mesh.
@@ -388,7 +418,7 @@ EOAPI void evas_canvas3d_mesh_index_data_copy_set(Evas_Canvas3D_Index_Format for
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Evas_Canvas3D_Index_Format evas_canvas3d_mesh_index_format_get(void);
+EOAPI Evas_Canvas3D_Index_Format evas_canvas3d_mesh_index_format_get(const Eo *obj);
 
 /**
  * @brief Get the count of the index data of the given mesh.
@@ -399,7 +429,7 @@ EOAPI Evas_Canvas3D_Index_Format evas_canvas3d_mesh_index_format_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI int evas_canvas3d_mesh_index_count_get(void);
+EOAPI int evas_canvas3d_mesh_index_count_get(const Eo *obj);
 
 /**
  * @brief Map the index buffer of the given mesh.
@@ -414,7 +444,7 @@ EOAPI int evas_canvas3d_mesh_index_count_get(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void *evas_canvas3d_mesh_index_data_map(void);
+EOAPI void *evas_canvas3d_mesh_index_data_map(Eo *obj);
 
 /**
  * @brief Unmap the index buffer of the given mesh.
@@ -423,7 +453,7 @@ EOAPI void *evas_canvas3d_mesh_index_data_map(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_index_data_unmap(void);
+EOAPI void evas_canvas3d_mesh_index_data_unmap(Eo *obj);
 
 /**
  * @brief Returns EINA_TRUE if frame was added and EINA_FALSE in other case.
@@ -432,7 +462,7 @@ EOAPI void evas_canvas3d_mesh_index_data_unmap(void);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI Eina_Bool evas_canvas3d_mesh_frame_exist(int frame);
+EOAPI Eina_Bool evas_canvas3d_mesh_frame_exist(Eo *obj, int frame);
 
 /**
  * @brief Add a key frame to the given mesh.
@@ -443,7 +473,7 @@ EOAPI Eina_Bool evas_canvas3d_mesh_frame_exist(int frame);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_frame_add(int frame);
+EOAPI void evas_canvas3d_mesh_frame_add(Eo *obj, int frame);
 
 /**
  * @brief Delete a key frame from the given mesh.
@@ -452,57 +482,63 @@ EOAPI void evas_canvas3d_mesh_frame_add(int frame);
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_frame_del(int frame);
+EOAPI void evas_canvas3d_mesh_frame_del(Eo *obj, int frame);
 
 /**
  * @brief Set the fog color and density for the given mesh.
  *
+ * @param[in] r The red component of the fog color.
  * @param[in] g The green component of the fog color.
  * @param[in] b The blue component of the fog color.
  * @param[in] a The transparency of fog.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_fog_color_set(Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
+EOAPI void evas_canvas3d_mesh_fog_color_set(Eo *obj, Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
 
 /**
  * @brief Set the fog color and density for the given mesh.
  *
+ * @param[out] r Pointer to receive red component of the fog color.
  * @param[out] g Pointer to receive green component of the fog color.
  * @param[out] b Pointer to receive blue component of the fog color.
  * @param[out] a Pointer to receive transparency of fog.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_fog_color_get(Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
+EOAPI void evas_canvas3d_mesh_fog_color_get(Eo *obj, Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
 
 /**
  * @brief Set the blending function for given mesh.
  *
+ * @param[in] sfactor Specifies how the red, green, blue, and alpha source
+ * blending factors are computed.
  * @param[in] dfactor Specifies how the red, green, blue, and alpha destination
  * blending factors are computed.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_blending_func_set(Evas_Canvas3D_Blend_Func sfactor, Evas_Canvas3D_Blend_Func dfactor);
+EOAPI void evas_canvas3d_mesh_blending_func_set(Eo *obj, Evas_Canvas3D_Blend_Func sfactor, Evas_Canvas3D_Blend_Func dfactor);
 
 /**
  * @brief Get blending blending function for given mesh.
  *
+ * @param[out] sfactor Pointer to receive source blendin factors key.
  * @param[out] dfactor Pointer to receive destination blendin factors key.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_blending_func_get(Evas_Canvas3D_Blend_Func *sfactor, Evas_Canvas3D_Blend_Func *dfactor);
+EOAPI void evas_canvas3d_mesh_blending_func_get(Eo *obj, Evas_Canvas3D_Blend_Func *sfactor, Evas_Canvas3D_Blend_Func *dfactor);
 
 /**
  * @brief Set the data of given mesh frame from the given primitive.
  *
+ * @param[in] frame Specifies data of which frame of given mesh will be set.
  * @param[in] primitive Specifies which data will be set.
  *
  * @ingroup Evas_Canvas3D_Mesh
  */
-EOAPI void evas_canvas3d_mesh_from_primitive_set(int frame, Evas_Canvas3D_Primitive *primitive);
+EOAPI void evas_canvas3d_mesh_from_primitive_set(Eo *obj, int frame, Evas_Canvas3D_Primitive *primitive);
 
 
 #endif
